Three terms recurrence
======================

.. currentmodule:: chaospy

Recurrence algorithms
---------------------

.. autosummary::
   :toctree: ../api

   modified_chebyshev
   lanczos
   stieltjes
   discretized_stieltjes
   analytical_stieltjes

Utility functions
-----------------

.. autosummary::
   :toctree: ../api

   coefficients_to_quadrature
